__version__ = "0.3.1"
install_requires = [
        "scikit-learn==0.24.2", 
        "tqdm==4.62.3", "SQLAlchemy==1.4.31", "docker==5.0.3",
        "psycopg2-binary"],
test_install_requires = ["pytest==7.1.2", "pytest-cov==3.0.0"]
URL = "https://github.com/gebauerm/ml_benchmark"
